##### begin loading data
source("utils_mer.txt")
source("utils_chart_maker.txt")

# lexicon
lex = read.csv("french_lexicon.csv")
lex$c.final = scale(as.numeric(lex$final), scale=T)
lex$c.mono = -scale(as.numeric(lex$size), scale=T)
lex$c.freq = scale(log(lex$V9+.01)) 
lex$c.nabers = scale(log(lex$nabers+1), scale=T)
summary(lex)

# experiment 1: judgments on 1-7 scale, natural stimuli
exp1 = read.csv("french_experiment_scale_natural.csv")
exp1$time = as.POSIXct(exp1$time)
exp1 = subset(exp1, type!="filler")
meta1 = read.csv("french_meta_scale_natural.csv")

# experiment 2: binary judgments, natural stimuli
exp2 = read.csv("french_experiment_binary_natural.csv")
exp2$time = as.POSIXct(exp2$time)
exp2 = subset(exp2, type!="filler")
meta2 = read.csv("french_meta_binary_natual.csv")

# experiment 3: binary judgments, artificial stimuli
exp3 = read.csv("french_experiment_binary_artificial.csv")
exp3$time = as.POSIXct(exp3$time)
exp3 = subset(exp3, type!="filler")
meta3 = read.csv("french_meta_binary_artificial.csv")


# various centerings etc.
exp1$c.size = scale(ifelse(exp1$size!="mono",0,1), scale=F)
exp1$c.type = scale(ifelse(exp1$type=="el/ej",0,1), scale=F)
exp1$c.final = scale(ifelse(exp1$finalConsonant=="j",0,1), scale=F)
exp1$c.length = scale((exp1$length-1)/4, scale=F)
exp2$c.base = scale((exp2$response1-1)/4, scale=F)
exp2$c.pl.l = scale(exp2$pl.l, scale=F)
exp2$c.size = scale(exp2$size=="mono", scale=F)
exp2$c.type = scale(exp2$type=="al/aj", scale=F)
exp2$c.order = scale(exp2$order, scale=F)
exp2$c.final = scale(as.numeric(exp2$finalConsonant), scale=F)
exp2$r.size = residuals(glm(exp2$size=="mono" ~ exp2$response1, family="binomial"))
exp2$r.type = residuals(glm(exp2$type=="al/aj" ~ exp2$response1, family="binomial"))
exp3$c.pl.l = scale(exp3$pl.l, scale=F)
exp3$c.base = scale((exp3$response1-1)/4, scale=F) ######
exp3$c.size = scale(exp3$size=="mono", scale=F)
exp3$c.type = scale(exp3$type=="al/aj", scale=F)
exp3$c.order = scale(exp3$order, scale=F)
exp3$c.final = scale(as.numeric(exp3$finalConsonant), scale=F)
exp3$r.size = scale(residuals(glm(exp3$size=="mono" ~ exp3$c.base, family="binomial")))
exp3$r.type = scale(residuals(glm(exp3$type=="al/aj" ~ exp3$c.base, family="binomial"))) 
exp1$l.sg_nabers = log(exp1$sg_nabers+1);
exp2$l.sg_nabers = log(exp2$sg_nabers+1);
exp3$l.sg_nabers = log(exp3$sg_nabers+1);
exp1$l.pl_nabers = log(exp1$pl_nabers+1);
exp2$l.pl_nabers = log(exp2$pl_nabers+1);
exp3$l.pl_nabers = log(exp3$pl_nabers+1);

# unified exp2 + exp3
exp2 = exp2[,-5] # useless column
exp2$xp = "exp2"
exp3$xp = "exp3"
exp23 = rbind(exp2, exp3)
exp23$c.exp = scale(as.numeric(exp23$xp=="exp2"), scale=F)
exp23$c.base = scale((exp23$response1-1)/4, scale=F) ######
exp23$c.size = scale(exp23$size=="mono", scale=F)
exp23$c.type = scale(exp23$type=="al/aj", scale=F)
exp23$c.final = scale(as.numeric(exp23$finalConsonant), scale=F)

##### done loading data
##### done loading data
##### done loading data





# LEXICON MODEL
glm0 = glm(faith<.5 ~ c.freq, family="binomial", data=lex);summary(glm0);kappa(glm0)
glm1 = update(glm0, .~. + c.final);summary(glm1);kappa(glm1)
glm2 = update(glm1, .~. + c.mono );summary(glm2);kappa(glm2)
anova(glm1, glm2, test="Chisq")
write.table(round(summary(glm2)$coef,2), sep="  &  ", eol="\\\\\n", quote=F)
kappa(glm2)
summary(glm2)
AIC(glm2)
BIC(glm2)

# these don't improve singificantly:
glm3 = update(glm2, .~. + c.mono:c.final);summary(glm3);anova(glm2, glm3, test="Chisq")
glm3 = update(glm2, .~. + c.mono:c.freq);summary(glm3);anova(glm2, glm3, test="Chisq")
glm3 = update(glm2, .~. + c.final:c.freq);summary(glm3);anova(glm2, glm3, test="Chisq")
glm3 = update(glm2, .~. + c.nabers);summary(glm3);anova(glm2, glm3, test="Chisq")



#### lexicon plot
quartz.fnc(cwidth=12,cheight=5,cname="r.French.lex.pdf")
par(family=myfont,ps=pointsize,mar=c(5,4,1.5,14),mfrow=c(1,1))
x = xtabs( ~ faith + type[drop=T] + size  , data=lex);x = cbind(x[,,1], x[,,2])
y = barplot(prop.table(x,2), width=colSums(x), yaxt="n", xaxt="n", col=gray(seq(.6,1,length.out=3)), space=c(.2,.03));
axis(2, at=seq(0,1,.2), paste(seq(0,1,.2)*100,"%",sep=""), cex.axis=1.5, las=1);
axis(1, at=y, tick=F, c("j", "l","j", "l"), cex.axis=2)
axis(1, at=(y[seq(1,3,2)]+y[seq(2,4,2)])/2, c("mono [a]","poly [a]"), cex.axis=2, line=2.5, tick=F)
legend(x=135, y=1, c("faithful","variable","alternating"), fill=gray(seq(1,.6,length.out=3)), cex=2, xpd=T)
if (chartmode=="pdf") {dev.off()}






######  experiments: descriptive stats
with(exp1, aggregate(response1, list(size), mean))
with(exp1, aggregate(response1, list(type), mean))
with(exp1, aggregate(response1, list(size, type), mean))

with(exp1, aggregate(response1, list(finalConsonant), mean))
with(exp1, aggregate(response1, list(finalConsonant, type), mean))
with(exp1, aggregate(response1, list(finalConsonant, size, type), mean))

aggregate(response1 ~ 1             , exp2, mean)
aggregate(response1 ~ finalConsonant, exp2, mean)
aggregate(response1 ~ size          , exp2, mean)
aggregate(response1 ~ type          , exp2, mean)

aggregate(pl.o ~ size          , exp2, mean)
aggregate(pl.o ~ type          , exp2, mean)
aggregate(pl.o ~ finalConsonant, exp2, mean)
aggregate(pl.o ~ finalConsonant, subset(exp2, type=="al/aj"), mean)

aggregate(response1 ~ 1             , exp3, mean)
aggregate(response1 ~ finalConsonant, exp3, mean)
aggregate(response1 ~ size          , exp3, mean)
aggregate(response1 ~ type          , exp3, mean)

aggregate(pl.o ~ size          , exp3, mean)
aggregate(pl.o ~ type          , exp3, mean)
aggregate(pl.o ~ finalConsonant, exp3, mean)
aggregate(pl.o ~ finalConsonant, subset(exp3, type=="al/aj"), mean)
aggregate(pl.o ~ finalConsonant  , exp3, mean)


######  experiment figures
quartz.fnc(cwidth=8,cheight=5,cname="r.french.scalar.pdf")
p=make.matrix(exp1, response1-1 ~ finalConsonant + type + size)
plot.french(p,6,"        preference for alternating plural")

quartz.fnc(cwidth=6,cheight=5,cname="r.french.binary.natural.base.pdf")
p=make.matrix(exp2, response1-1 ~ finalConsonant + type + size)
plot.french(p,4,"         mean rating of singular")

quartz.fnc(cwidth=6,cheight=5,cname="r.french.binary.natural.oplural.pdf")
p=make.matrix(exp2, pl.o ~ finalConsonant + type + size)
plot.french(p,1,"          acceptability of alternating plural")

quartz.fnc(cwidth=6,cheight=5,cname="r.french.binary.artificial.base.pdf")
p=make.matrix(exp3, response1-1 ~ finalConsonant + type + size)
plot.french(p,4,"         mean rating of singular")

quartz.fnc(cwidth=6,cheight=5,cname="r.french.binary.artificial.oplural.pdf")
p=make.matrix(exp3, pl.o ~ finalConsonant + type + size)
plot.french(p,1,"          acceptability of alternating plural")





# exp 1 regression
library(lme4.0) # Loading lmer 0.999999
Sys.time();lmer40.exp1f = lmer(response1 ~ c.size*c.type*c.final + (1+c.type*c.final|stem) + (1+c.size*c.type*c.final|userCode), data=exp1, control = list(maxIter = 3000));Sys.time(); 
lmer40.exp1f
max(vif.mer(lmer40.exp1f))
kappa.mer(lmer40.exp1f)
maxcorr.mer(lmer40.exp1f)
#
write.table(round(summary(lmer40.exp1f)@coefs,2), quote=F, sep="  &  ", eol="\\\\\n")
round(2*(1-pnorm(abs(summary(lmer40.exp1f)@coefs[,3]))),4)


# exp2 regression
library(lme4.0)
Sys.time(); lmer.exp2f9 = 
  lmer(pl.o ~ c.base + c.size * c.type * c.final + 
         (1 + c.size * c.type * c.final-c.size:c.type:c.final-c.type:c.final-c.size:c.final|userCode) + 
         (1|stem),
       data=exp2, family="binomial", control = list(maxIter = 3000));Sys.time();
lmer.exp2f9
write.table(round(summary(lmer.exp2f9)@coefs,2), quote=F, sep="  &  ", eol="\\\\\n")
max(vif.mer(lmer.exp2f9))
kappa.mer(lmer.exp2f9)




# exp3 regression
library(lme4.0)
Sys.time(); lmer.exp3f9 = 
  lmer(pl.o ~ c.base + c.size * c.type * c.final + 
         (1 + c.size * c.type * c.final - c.size:c.type:c.final-c.size:c.final-c.type:c.final |userCode) +
         (1 |stem), 
       data=exp3, family="binomial", 
       control = list(maxIter = 30000)); Sys.time(); 
lmer.exp3f9
write.table(round(summary(lmer.exp3f9)@coefs,2), quote=F, sep="  &  ", eol="\\\\\n")
max(vif.mer(lmer.exp3f9))
kappa.mer(lmer.exp3f9)













##### MAXENT vs. LEXICON (all three experiments)
l = aggregate(response1 ~ size + finalConsonant + type, exp1, mean)
l$maxent = c(.163, .414, .349, .662, .002, .006, .004, .015)
l$final = gsub("e","ɛ",ifelse(l$finalConsonant=="l", substr(l$type,0,2), substr(l$type,4,5)))
l$label = paste(l$size, l$final, sep="/")
l = merge(l, aggregate(pl.o ~ size + finalConsonant + type, exp2, mean))
l.item = aggregate(response1 ~ size + finalConsonant + type + item_l, exp1, mean)
l.item = merge(l.item, l[,-c(4,8)])
l.item = merge(l.item, aggregate(pl.o ~ size + finalConsonant + type + item_l, exp2, mean), all.x=T)
colnames(l.item)[c(5,9)] = c("exp1","exp2")
l.item = merge(l.item, aggregate(pl.o ~ size + finalConsonant + type + item_l, exp3, mean), all.x=T)
l.item$pch = ifelse(l.item$size=="mono",1,4)
colnames(l.item)[10] = "exp3"

summary(replicate(1000, cor.test(jitter(l.item$exp1), jitter(l.item$maxent), method="s")$estimate))
summary(replicate(1000, cor.test(jitter(l.item$exp2), jitter(l.item$maxent), method="s")$estimate))
summary(replicate(1000, cor.test(jitter(l.item$exp3), jitter(l.item$maxent), method="s")$estimate))

quartz.fnc(cwidth=12,cheight=5,cname="r.french.lex.vs.exp.byitem.pdf")
par(family=myfont,ps=pointsize,mar=c(5,5,2,2),mfrow=c(1,3))
plot(exp1 ~ jitter(maxent, factor=20), l.item, cex=1, ylim=c(1,7.0), xaxt="n", main="Experiment 1 (n=185)", frame.plot=F, cex.axis=1.4, cex.lab=1.8, cex.main=2, xlab="MaxEnt model predictions", ylab="mean participant response")
axis(1, seq(0,.6,.2), paste(seq(0,.6,.2)*100, "%",sep=""), cex.axis=1.4)
abline(lm(exp1 ~ maxent, l.item), col="gray50")
text(.6, 1, "ρ = .78", cex=2, xpd=T)
#
plot(exp2 ~ jitter(maxent, factor=20), l.item, cex=1, xaxt="n", yaxt="n", main="Experiment 2 (n=52)", frame.plot=F, ylim=c(0,1.05), cex.axis=1.4, cex.lab=1.8, cex.main=2, xlab="MaxEnt model predictions", ylab="mean participant response")
axis(1, seq(0,.6,.2), paste(seq(0,.6,.2)*100, "%",sep=""), cex.axis=1.4)
axis(2, seq(0,1,.2), paste(seq(0,1,.2)*100, "%",sep=""), cex.axis=1.4)
abline(lm(exp2 ~ maxent, l.item), col="gray50")
text(.6, 0, "ρ = .56", cex=2, xpd=T)
#
plot(exp3 ~ jitter(maxent, factor=20), l.item, cex=1, xaxt="n", yaxt="n", main="Experiment 3 (n=71)", frame.plot=F, ylim=c(0,1.05), cex.axis=1.4, cex.lab=1.8, cex.main=2, xlab="MaxEnt model predictions", ylab="mean participant response")
axis(1, seq(0,.6,.2), paste(seq(0,.6,.2)*100, "%",sep=""), cex.axis=1.4)
axis(2, seq(0,1,.2), paste(seq(0,1,.2)*100, "%",sep=""), cex.axis=1.4)
abline(lm(exp3 ~ maxent, l.item), col="gray50")
text(.6, 0, "ρ = .72", cex=2, xpd=T)
if (chartmode=="pdf") {dev.off()}






# neighborhood density effects in monos and polys separately
# exp 1
x = unique(exp1[,c("item_l", "size", "l.sg_nabers", "l.pl_nabers")]);
x = merge(x, aggregate(response1 ~ item_l, exp1, mean))

with(x, cor.test(response1, l.sg_nabers))[c("estimate","p.value")]
with(x, cor.test(response1, l.pl_nabers))[c("estimate","p.value")]

with(subset(x, size=="mono"), cor.test(response1, l.sg_nabers))
with(subset(x, size=="mono"), cor.test(response1, l.pl_nabers))
with(subset(x, size!="mono"), cor.test(response1, l.sg_nabers))
with(subset(x, size!="mono"), cor.test(response1, l.pl_nabers))

# exp 2 
x = unique(exp2[,c("item_l", "size", "l.sg_nabers", "l.pl_nabers")]);
x = merge(x, aggregate(pl.o ~ item_l, exp2, mean))

with(x, cor.test(pl.o, l.sg_nabers))
with(x, cor.test(pl.o, l.pl_nabers))

with(subset(x, size=="mono"), cor.test(pl.o, l.sg_nabers))
with(subset(x, size=="mono"), cor.test(pl.o, l.pl_nabers))
with(subset(x, size!="mono"), cor.test(pl.o, l.sg_nabers))
with(subset(x, size!="mono"), cor.test(pl.o, l.pl_nabers))

# exp 3
x = unique(exp2[,c("item_l", "size", "l.sg_nabers", "l.pl_nabers")]);
x = merge(x, aggregate(pl.o ~ item_l, exp3, mean))

with(x, cor.test(pl.o, l.sg_nabers))
with(x, cor.test(pl.o, l.pl_nabers))

with(subset(x, size=="mono"), cor.test(pl.o, l.sg_nabers))
with(subset(x, size=="mono"), cor.test(pl.o, l.pl_nabers))
with(subset(x, size!="mono"), cor.test(pl.o, l.sg_nabers))
with(subset(x, size!="mono"), cor.test(pl.o, l.pl_nabers))







